@@ -186,7 +186,11 @@ class HdDB:
             fields = self.execute(fields_query, [tbl]).fetchdf()
 
             # Convert DataFrames to JSON objects
-            data_json = json.loads(data.fillna("").to_json(orient="records"))
+            data_json = json.loads(
+                data.fillna("")
+                .replace({"NaN": "", "nan": ""})
+                .to_json(orient="records")
+            )
             fields_json = fields.to_dict(orient="records")
 
             return {"data": data_json, "fields": fields_json}
